darkhistory.physics.inj_rate — DarkHistory documentation

# darkhistory.physics.inj_rate

`darkhistory.physics.` `inj_rate`(inj_type, rs, mDM=None, sigmav=None, lifetime=None)

  Dark matter annihilation/decay energy injection rate.

  Parameters: | inj_type : {‘swave’, ‘decay’} Type of injection. rs : float The redshift of injection. mDM : float, optional DM mass in eV. sigmav : float, optional Annihilation cross section in cm-3s-1. lifetime : float, optional Decay lifetime in s.
  Returns: | float The dE/dV_dt injection rate in eV cm-3s-1.

#### Previous topic

darkhistory.physics.get_optical_depth

#### Next topic

darkhistory.physics.struct_boost_func

### This Page

Show Source